@@ -23,3 +23,18 @@ test_that("Equality with t()", {
 })
 
 ################################################################################
+
+test_that("option 'FBM.dir' works", {
+
+  X <- FBM(10, 10)
+
+  dir <- tempfile(pattern = "tmpdir")
+  opt <- options(FBM.dir = dir)
+
+  expect_message(X2 <- big_transpose(X), "Creating directory")
+  expect_identical(normalizePath(dirname(X2$backingfile)), normalizePath(dir))
+
+  options(opt)  # back to normal
+})
+
+################################################################################
